@@ -21,12 +21,9 @@
 
 from pybtex.backends import BaseBackend
 
-file_extension = 'bbl'
 
 class Backend(BaseBackend):
-    name = 'latex'
-    suffixes = '.bbl',
-
+    default_suffix = '.bbl'
     symbols = {
         'ndash': u'--',
         'newblock': u'\n\\newblock ',
@@ -35,8 +32,13 @@ class Backend(BaseBackend):
     
     def format_tag(self, tag_name, text):
         return ur'\%s{%s}' % (tag_name, text)
+
+    def format_href(self, url, text):
+        return ur'\href{%s}{%s}' % (url, text)
     
     def write_prologue(self):
+        self.output(self.formatted_bibliography.preamble + u'\n')
+
         longest_label = self.formatted_bibliography.get_longest_label()
         self.output(u'\\begin{thebibliography}{%s}' % longest_label)
 
