@@ -39,6 +39,104 @@ class PybtexOption(optparse.Option):
     ATTRS = optparse.Option.ATTRS + ['plugin_group']
     TYPES = optparse.Option.TYPES + ('load_plugin',)
     TYPE_CHECKER = dict(optparse.Option.TYPE_CHECKER, load_plugin=check_plugin)
+    STANDARD_OPTIONS = {}
+
+
+make_option = PybtexOption
+
+
+def make_standard_option(*args, **kwargs):
+    option = make_option(*args, **kwargs)
+    PybtexOption.STANDARD_OPTIONS[option.dest] = option
+    return option
+
+
+def standard_option(name):
+    return PybtexOption.STANDARD_OPTIONS[name]
+
+
+make_standard_option(
+    '-f', '--bibliography-format', dest='bib_format',
+    help='bibliograpy format (%plugin_choices)',
+    type='load_plugin',
+    plugin_group='pybtex.database.input',
+    metavar='FORMAT',
+)
+
+make_standard_option(
+    '-b', '--output-backend', dest='output_backend',
+    help='output backend (%plugin_choices)',
+    type='load_plugin',
+    plugin_group='pybtex.backends',
+    metavar='BACKEND',
+)
+
+make_standard_option(
+    '--min-crossrefs',
+    type='int', dest='min_crossrefs',
+    help='include item after NUMBER crossrefs; default 2',
+    metavar='NUMBER',
+)
+
+make_standard_option(
+    '--keyless-bibtex-entries',
+    action='store_true', dest='keyless_entries',
+    help='allow BibTeX entries without keys and generate unnamed-<number> keys for them'
+)
+
+make_standard_option(
+    '-s', '--style',
+    type='string', dest='style', help='bibliography formatting style',
+)
+
+make_standard_option(
+    '--label-style', dest='label_style',
+    help='label formatting style (%plugin_choices)',
+    type='load_plugin',
+    plugin_group='pybtex.style.labels',
+    metavar='STYLE',
+)
+
+make_standard_option(
+    '--name-style', dest='name_style',
+    help='name formatting style (%plugin_choices)',
+    type='load_plugin',
+    plugin_group='pybtex.style.names',
+    metavar='STYLE',
+)
+
+make_standard_option(
+    '--sorting-style', dest='sorting_style',
+    help='sorting style (%plugin_choices)',
+    type='load_plugin',
+    plugin_group='pybtex.style.sorting',
+    metavar='STYLE',
+)
+
+make_standard_option(
+    '--abbreviate-names',
+    action='store_true', dest='abbreviate_names',
+    help='use abbreviated name formatting style',
+)
+
+make_standard_option(
+    '-e', '--encoding',
+    action='store', type='string', dest='encoding',
+    help='default encoding',
+    metavar='ENCODING',
+)
+
+make_standard_option(
+    '--input-encoding',
+    action='store', type='string', dest='input_encoding',
+    metavar='ENCODING',
+)
+
+make_standard_option(
+    '--output-encoding',
+    action='store', type='string', dest='output_encoding',
+    metavar='ENCODING',
+)
 
 
 BaseHelpFormatter = optparse.IndentedHelpFormatter
@@ -54,9 +152,6 @@ class PybtexHelpFormatter(BaseHelpFormatter):
         return result
 
 
-make_option = PybtexOption
-
-
 class CommandLine(object):
     options = ()
     option_defaults = None
@@ -110,12 +205,19 @@ class CommandLine(object):
             for arg in args
         ]
 
+    def _extract_kwargs(self, options):
+        return dict(
+            (option.dest, getattr(options, option.dest))
+            for option_group, option_list in self.options
+            for option in option_list
+        )
+
     def main(self):
-        args = self.recognize_legacy_optons(sys.argv[1:])
-        options, args = self.opt_parser.parse_args(args)
+        argv = self.recognize_legacy_optons(sys.argv[1:])
+        options, args = self.opt_parser.parse_args(argv)
         if len(args) != self.num_args:
             self.opt_parser.print_help()
             sys.exit(1)
-
-        self.run(options, args)
+        kwargs = self._extract_kwargs(options)
+        self.run(*args, **kwargs)
         sys.exit(errors.error_code)
