@@ -67,9 +67,6 @@ class PrettyTreeBuilder(object):
 class Writer(BaseWriter):
     """Outputs BibTeXML markup"""
 
-    name = 'bibtexml'
-    suffixes = '.xml', '.bibtexml'
-
     def write_stream(self, bib_data, stream):
         def write_persons(persons, role):
             if persons:
